fname

package
v0.0.0-...-bdaebf0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CallerFuncName

func CallerFuncName(skip int) string

CallerFuncName returns the function name of the caller at the given stack depth.

skip meanings:

0 = CallerFuncName
1 = function calling CallerFuncName
2 = parent of that function
etc...

func CallerFuncShortName

func CallerFuncShortName(skip int) string

CallerFuncShortName returns the short name of the caller at the given stack depth.

func CurrentFuncName

func CurrentFuncName() string

CurrentFuncName returns the name of the function that calls CurrentFuncName.

func CurrentFuncShortName

func CurrentFuncShortName() string

CurrentFuncShortName returns the short name of the calling function.

func FuncName

func FuncName(fn any) string

FuncName returns the full function name in the form <prefix>.(*<type>).<function>

func ShortFuncName

func ShortFuncName(full string) string

ShortFuncName returns just the function/method name without package or type path.

Types

This section is empty.

Jump to