Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CallerFuncName ¶
CallerFuncName returns the function name of the caller at the given stack depth.
skip meanings:
0 = CallerFuncName 1 = function calling CallerFuncName 2 = parent of that function etc...
func CallerFuncShortName ¶
CallerFuncShortName returns the short name of the caller at the given stack depth.
func CurrentFuncName ¶
func CurrentFuncName() string
CurrentFuncName returns the name of the function that calls CurrentFuncName.
func CurrentFuncShortName ¶
func CurrentFuncShortName() string
CurrentFuncShortName returns the short name of the calling function.
func ShortFuncName ¶
ShortFuncName returns just the function/method name without package or type path.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.